@@ -152,7 +152,7 @@ qq.formula <-
 
     dots <- foo$dots # arguments not processed by trellis.skeleton
     foo <- foo$foo
-    foo$call <- sys.call(sys.parent())
+    foo$call <- sys.call(sys.parent()); foo$call[[1]] <- quote(qq)
 
     ## Step 2: Compute scales.common (leaving out limits for now)
 
@@ -187,7 +187,7 @@ qq.formula <-
             else if (is.numeric(xlog)) xlog
             else if (xlog == "e") exp(1)
         ## x <- log(x, xbase)  later, in panel.args
-        if (have.xlim) xlim <- log(xlim, xbase)
+        if (have.xlim) xlim <- logLimits(xlim, xbase)
     }
     if (have.ylog)
     {
@@ -197,7 +197,7 @@ qq.formula <-
             else if (is.numeric(ylog)) ylog
             else if (ylog == "e") exp(1)
         ## y <- log(y, ybase)
-        if (have.ylim) ylim <- log(ylim, ybase)
+        if (have.ylim) ylim <- logLimits(ylim, ybase)
     }
     
     ## Step 5: Process cond
@@ -253,10 +253,10 @@ qq.formula <-
                 else f.value(n)
             foo$panel.args[[packet.number]] <-
                 list(x =
-                     fast.quantile(x = x.val, probs = p,
+                     quantile(x = x.val, probs = p, # was fast.quantile 
                                    type = qtype, na.rm = TRUE),
                      y =
-                     fast.quantile(x = y.val, probs = p,
+                     quantile(x = y.val, probs = p, # was fast.quantile 
                                    type = qtype, na.rm = TRUE))
         }
         else
