@@ -175,7 +175,9 @@ panel.xyplot <-
                         lty = lty, col = col.line, lwd = lwd, ...)
         }
         if ("r" %in% type) panel.lmline(x, y, col = col.line, lty = lty, lwd = lwd, ...)
-        if ("smooth" %in% type) panel.loess(x, y, col = col.line, lty = lty, lwd = lwd, ...)
+        if ("smooth" %in% type)
+            panel.loess(x, y, horizontal = horizontal,
+                        col = col.line, lty = lty, lwd = lwd, ...)
         if ("a" %in% type)
             panel.linejoin(x, y, 
                            horizontal = horizontal,
@@ -339,7 +341,7 @@ xyplot.formula <-
             else if (xlog == "e") exp(1)
 
         x <- log(x, xbase)
-        if (have.xlim) xlim <- log(xlim, xbase)
+        if (have.xlim) xlim <- logLimits(xlim, xbase)
     }
     if (have.ylog)
     {
@@ -350,7 +352,7 @@ xyplot.formula <-
             else if (ylog == "e") exp(1)
 
         y <- log(y, ybase)
-        if (have.ylim) ylim <- log(ylim, ybase)
+        if (have.ylim) ylim <- logLimits(ylim, ybase)
     }
     
     ## Step 5: Process cond
